<?php
/**
 * All Email Template admin based functions
 */

/**
 * Plugin activation / upgrade hook
 */
function nlws_et_activate() {
	// Only send if the plugin hasn't been activated before
	$isinstalled = get_option('nlws_et_version');
	
	if ( ( $isinstalled < NLWS_ET_VERSION) || !$isinstalled )  {	
		// Update version
		update_option( 'nlws_et_version', NLWS_ET_VERSION );
		
		// Create the initial table if it doesn't exist
		global $wpdb;
		$SQL = "CREATE TABLE `" . NLWS_ET_TABLE . "` (
			ID INT(11) NOT NULL AUTO_INCREMENT,  
			name VARCHAR(255) NOT NULL,  
			use_global_settings TINYINT(1) DEFAULT NULL,  
			from_email VARCHAR(255) DEFAULT NULL,  
			from_name VARCHAR(255) DEFAULT NULL,  
			header TEXT DEFAULT NULL,  
			footer TEXT DEFAULT NULL,  
			subject VARCHAR(255) NOT NULL,  
			content TEXT NOT NULL,  
			PRIMARY KEY  (ID)
		)
		ENGINE = MYISAM
		AUTO_INCREMENT = 1
		CHARACTER SET latin1
		COLLATE latin1_swedish_ci;
		";
		
		$SQL.= "CREATE TABLE wp_nlws_email_logs(
			ID INT(11) NOT NULL AUTO_INCREMENT,
			`date` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
			`to` VARCHAR(180) NOT NULL,
			content TEXT NOT NULL,
			subject VARCHAR(255) NOT NULL,
			PRIMARY KEY  (ID)
		);";
		
		require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
		dbDelta($SQL);
		
		// Check to see if there are any default settings
		$hasglobaloptions = get_option('nlws_et_settings');
		
		if (!$hasglobaloptions) {
			/**
			 * Create the default header
			 */
			$defaultheader = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">' . "\n";
			$defaultheader.= '<html>' . "\n";
			$defaultheader.= "\t" . '<head>' . "\n";
			$defaultheader.= "\t" . '</head>' . "\n";
			$defaultheader.= "\t" . '<body style="background: #eee;">' . "\n";
			$defaultheader.= "\t\t" . '<div style="width: 600px; margin: 20px auto 0; padding: 20px 20px 0;">' . "\n";
			$defaultheader.= "\t\t\t" . '<a href="' . get_bloginfo('siteurl') . '" title="' . get_bloginfo('name') . '" /><img src="' . NLWS_ET_URL . 'images/etemplates-email.png" alt="' . get_bloginfo('name') . '"/></a>' . "\n";
			$defaultheader.= "\t\t" . '</div>' . "\n";
			$defaultheader.= "\t\t" . '<div style="border:1px solid #ccc; background: #ddd; width: 600px; margin: 10px auto 20px; padding: 30px; font-size: 20px;">' . "\n";
			$defaultheader.= "\t\t\t" . '<!-- BEGIN: Email Content -->' . "\n";
			
			/**
			 * Create the default footer
			 */
			$defaultfooter = "\t\t\t" . '<!-- END: Email Content -->' . "\n";
			$defaultfooter.= "\t\t" . '</div>' . "\n";
			$defaultfooter.= "\t" . '</body>' . "\n";
			$defaultfooter.= '</html>';
			
			$defaultoptions = array(
				"default_email" => get_option('admin_email'),
				"default_from" => get_option('blogname'),
				"send_as_html" => 1,
				"default_header" => $defaultheader,
				"default_footer" => $defaultfooter
			);
			update_option('nlws_et_settings', $defaultoptions);
		}
	}
}


/**
 * Register settings
 */
function nlws_et_admin_init() {
	// Register the settings
	register_setting( 'nlws_et_settings', 'nlws_et_settings' );
	register_setting( 'nlws_et_templates', 'nlws_et_templates' );
}


/**
 * Add options page
 */
function nlws_et_plugin_menu() {
	$icon = NLWS_ET_URL . 'images/mail-16.png';
	add_object_page('eTemplates', 'eTemplates', 'manage_options', 'nlws-et', '', $icon);
	$settings_page = add_submenu_page('nlws-et', 'Global Settings', 'Global Settings', 'manage_options', 'nlws-et', 'nlws_et_global_settings');
	$templates_page = add_submenu_page('nlws-et', 'Templates', 'Templates', 'manage_options', 'nlws-et-templates', 'nlws_et_templates');
	$log_page = add_submenu_page('nlws-et', 'Email Logs', 'Email Logs', 'manage_options', 'nlws-et-log', 'nlws_et_log');
	$help_page = add_submenu_page('nlws-et', 'Help', 'Help', 'manage_options', 'nlws-et-help', 'nlws_et_help');
	
	add_action ('admin_head-' . $settings_page, 'nlws_et_settings_head');
	add_action ('admin_head-' . $templates_page, 'nlws_et_templates_head');
	add_action ('admin_head-' . $help_page, 'nlws_et_help_head');
	add_action ('admin_head-' . $log_page, 'nlws_et_log_head');
}


/**
 * Settings Page Header Injection
 */
function nlws_et_settings_head() {
	echo '<link href="' . NLWS_ET_URL . 'css/et-default.css" rel="stylesheet" type="text/css" />';
	echo '<script type="text/javascript" src="' . NLWS_ET_URL . 'js/jquery.validate.min.js"></script>';
	echo '<script type="text/javascript" src="' . NLWS_ET_URL . 'js/et-settings.js"></script>';
}


/**
 * Templates Page Header Injection
 */
function nlws_et_templates_head() {
	echo '<link href="' . NLWS_ET_URL . 'css/et-default.css" rel="stylesheet" type="text/css" />';
	echo '<script type="text/javascript" src="' . NLWS_ET_URL . 'js/jquery.validate.min.js"></script>';
	echo '<script type="text/javascript" src="' . NLWS_ET_URL . 'js/et-templates.js"></script>';
}

/**
 * Log Page Header Injection
 */
function nlws_et_log_head() {
	echo '<link href="' . NLWS_ET_URL . 'css/et-default.css" rel="stylesheet" type="text/css" />';
	wp_enqueue_style('thickbox');
	wp_enqueue_script('thickbox');
}

/**
 * Help Page Header Injection
 */
function nlws_et_help_head() {
	echo '<link href="' . NLWS_ET_URL . 'css/et-help.css" rel="stylesheet" type="text/css" />';
}

?>